pub struct SttContextPool { /* private fields */ }Expand description
STT context residency + singleflight loader (JOE-1784).
Own one per crate::AurumEngine, or share via process_global_stt_pool.
Implementations
Sourceimpl SttContextPool
impl SttContextPool
pub fn new() -> Self
Sourcepub fn resident_len(&self) -> usize
pub fn resident_len(&self) -> usize
Number of resident (loaded) contexts in this pool.
Sourcepub fn get_or_load_pin(
&self,
model_path: &Path,
model_name: &str,
gov: &Arc<ResourceGovernor>,
) -> Result<RegistryPin<WhisperContext>>
pub fn get_or_load_pin( &self, model_path: &Path, model_name: &str, gov: &Arc<ResourceGovernor>, ) -> Result<RegistryPin<WhisperContext>>
Load or reuse a context and return an active registry pin held for the whole operation (JOE-1646). No unpinned Arc is returned to callers.
pub fn get_or_load( &self, model_path: &Path, model_name: &str, gov: &Arc<ResourceGovernor>, ) -> Result<Arc<WhisperContext>>
pub fn contains(&self, model_path: &Path, model_name: &str) -> bool