pub fn build_support_bundle(
cfg: &Config,
user_notes: Option<String>,
) -> SupportBundleExpand description
Build a support bundle from the effective config (no network, no downloads).
pub fn build_support_bundle(
cfg: &Config,
user_notes: Option<String>,
) -> SupportBundleBuild a support bundle from the effective config (no network, no downloads).