pub struct PartialClock { /* private fields */ }Expand description
Tracks wall-clock spacing between partial attempts.
Implementations
Sourceimpl PartialClock
impl PartialClock
pub fn new(policy: PartialWindowPolicy) -> Self
pub fn policy(&self) -> &PartialWindowPolicy
Sourcepub fn interval_elapsed(&self) -> bool
pub fn interval_elapsed(&self) -> bool
True if enough time has elapsed since the last partial (or never ran).
Sourcepub fn ready(&self, samples: &[f32]) -> bool
pub fn ready(&self, samples: &[f32]) -> bool
Ready for another partial given full buffer samples. Energy is evaluated on the same rolling window that would be decoded.
Sourcepub fn take_partial_slice<'a>(
&mut self,
samples: &'a [f32],
) -> Option<&'a [f32]>
pub fn take_partial_slice<'a>( &mut self, samples: &'a [f32], ) -> Option<&'a [f32]>
Slice + mark if ready; returns None if not ready.