Privacy-safe support bundles for early adopters (JOE-1728).
Bundles never include API keys, audio, transcripts, or private absolute
home paths by default. Paths are redacted to $HOME / $CACHE tokens.
Structs
- Support
Bundle - Offline, allowlist-based diagnostic package.
Constants
- SUPPORT_
BUNDLE_ VERSION - Support bundle schema version.
Functions
- build_
support_ bundle - Build a support bundle from the effective config (no network, no downloads).
- default_
bundle_ path - Default path suggestion for a new support bundle file.